==> exo.portal.parent-3.2.1-PLF-source-release.zip: exo.portal.parent-3.2.1-PLF/component/portal/src/main/java/org/exoplatform/portal/config/serialize/PortletApplication.java <==
/**
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.exoplatform.portal.config.serialize;

import org.exoplatform.portal.config.model.Application;
import org.exoplatform.portal.config.model.ApplicationType;
import org.exoplatform.portal.pom.data.ApplicationData;
import org.exoplatform.portal.pom.spi.portlet.Portlet;

/**
 * We keep that subclass here to please JiBX crap.
 *
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public class PortletApplication extends Application<Portlet>
{

   public PortletApplication(ApplicationData<Portlet> preferencesApplicationData)
   {
      super(preferencesApplicationData);
   }

   public PortletApplication(ApplicationType<Portlet> preferencesApplicationType, String storageId)
   {
      super(preferencesApplicationType, storageId);
   }

   public PortletApplication(ApplicationType<Portlet> preferencesApplicationType)
   {
      super(preferencesApplicationType);
   }
}

==> exo.portal.parent-4.4.2-PLF-source-release.zip: exo.portal.parent-4.4.2-PLF/component/portal/src/main/java/org/exoplatform/portal/config/serialize/PortletApplication.java <==
/**
 * Copyright (C) 2009 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.exoplatform.portal.config.serialize;

import org.exoplatform.portal.config.model.Application;
import org.exoplatform.portal.config.model.ApplicationType;
import org.exoplatform.portal.pom.data.ApplicationData;
import org.exoplatform.portal.pom.spi.portlet.Portlet;

/**
 * We keep that subclass here to please JiBX crap.
 *
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 * @version $Revision$
 */
public class PortletApplication extends Application<Portlet> {

    public PortletApplication(ApplicationData<Portlet> preferencesApplicationData) {
        super(preferencesApplicationData);
    }

    public PortletApplication(ApplicationType<Portlet> preferencesApplicationType, String storageId) {
        super(preferencesApplicationType, storageId);
    }

    public PortletApplication() {
        super(ApplicationType.PORTLET);
    }
}
